#!/bin/bash
#------------------------------------------------------------------------------
# Copyright (c) 2020 Olaf Jaehrling <eisfair(at)ojaehrling.(dot)de>
#
# Creation:     17.03.2014 by Olaf Jaehrling
# Last Update:  02.09.2020 by Olaf Jaehrling
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License
#------------------------------------------------------------------------------


package='vlan'
package_name='vlan'

# include eislib
. /var/install/include/eislib
. /var/install/include/configlib

#exec 2>/tmp/centerim_up-trace.log
#set -x
mecho -info "adding new parameter(s) ..."
### ---------------------------------------------------------------------------
### Set the default values for configuration
### ---------------------------------------------------------------------------
START_VLAN='yes'                      # activate VLAN 802.1Q
VLAN_DEV_N='1'
VLAN_DEV_1_DEV='lan1'
VLAN_DEV_1_VID='25'   
VLAN_DEV_1_IPV4ADDR='192.168.10.1/24'
VLAN_DEV_1_IPV6ADDR='fd0c:1a0:1234:bb01::100/128'
VLAN_DEV_1_ROUTE=''
VLAN_DEV_1_DEFAULT='no'
VLAN_DEV_1_DEFAULTGW='192.168.10.10'
VLAN_DEV_1_METRIC='1024'

### ---------------------------------------------------------------------------
### read old configuration and rename old variables
### ---------------------------------------------------------------------------
read_old_variables()
{
 # read old values
 if [ -f /etc/config.d/${package_name} ]
 then
     . /etc/config.d/${package_name}
 fi
}

#------------------------------------------------------------------------
# modify variables
#------------------------------------------------------------------------
mecho -info "modifying parameter(s) ..."
mecho -warn "... read documentation for modified and/or added parameter(s)!"

modify_variables ()
{
 if [ -f /etc/config.d/${package_name} ]
 then
     . /etc/config.d/${package_name}
     if grep -q ENABLE_VLAN /etc/config.d/${package_name}
     then
         START_VLAN=$ENABLE_VLAN
     fi

 fi


}
### ---------------------------------------------------------------------------
### Write config and default files
### ---------------------------------------------------------------------------
make_config_file()
{
 internal_conf_file=${1}
 (
 #--------------------------------------------------------------------------------
 printgpl -conf ${package_name} ${DATUM} "OJae" "Olaf Jaehrling eisfair(at)ojaehrling(dot)de"
 #--------------------------------------------------------------------------------
 #--------------------------------------------------------------------------------
 printgroup "vlan configuration"
 #--------------------------------------------------------------------------------
 printvar "START_VLAN" "aktivere VLAN 802.1Q"
 printvar "VLAN_DEV_N" "Anzahl der Vlans"
 #--------------------------------------------------------------------------------
 printgroup "vlan device configuration"
 #--------------------------------------------------------------------------------

 idx=1
 while [ "$VLAN_DEV_N" -ge "$idx" ]
 do
     printvar 'VLAN_DEV_'${idx}'_DEV'      "Auf welchem Interface soll das vlan aufgesetzt werden?"
     printvar 'VLAN_DEV_'${idx}'_VID'      "vlan-id"
     printvar "VLAN_DEV_${idx}_IPV4ADDR" "IPv4 Adresse"
     printvar "VLAN_DEV_${idx}_IPV6ADDR" "IPv6 Adresse"
     printvar "VLAN_DEV_${idx}_ROUTE" "Bei IPv6 die Route fuer das IPv6 Netz"
     printvar "VLAN_DEV_${idx}_DEFAULT" "geht darueber der Default Gateway?"
     printvar "VLAN_DEV_${idx}_DEFAULTGW" "Bei IPv6 der Default Gateway"
     printvar "VLAN_DEV_${idx}_METRIC" "Die Metric für diesen Gateway"
     idx=`/usr/bin/expr $idx + 1`
 done

 #--------------------------------------------------------------------------------
 printend
 #--------------------------------------------------------------------------------

 ) > ${internal_conf_file}
 # Set rights
 chmod 0600 ${internal_conf_file}
 chown root ${internal_conf_file}
}

### -------------------------------------------------------------------------
### Create the check.d file
### -------------------------------------------------------------------------

make_check_file()
{
#--------------------------------------------------------------------------------
printgpl -check ${package_name} ${DATUM} "OJae" "Olaf Jaehrling <eisfair[at]ojaehrling[dot]de>" >/etc/check.d/${package_name}
#--------------------------------------------------------------------------------
cat >>/etc/check.d/${package_name} <<EOF
# Variable OPT_VARIABLE VARIABLE_N VALUE
START_VLAN                 -                      -           YESNO
VLAN_DEV_N               START_VLAN               -           NUMERIC
VLAN_DEV_%_DEV           START_VLAN             VLAN_DEV_N    VLAN_INTERFACE_CUI
VLAN_DEV_%_VID           START_VLAN             VLAN_DEV_N    NUMERIC
VLAN_DEV_%_IPV4ADDR      START_VLAN             VLAN_DEV_N    VLAN_IP4
VLAN_DEV_%_IPV6ADDR      START_VLAN             VLAN_DEV_N    VLAN_ADD
VLAN_DEV_%_ROUTE         START_VLAN             VLAN_DEV_N    VLAN_ADD
VLAN_DEV_%_DEFAULT       START_VLAN             VLAN_DEV_N    YESNO
VLAN_DEV_%_DEFAULTGW     VLAN_DEV_%_DEFAULT     VLAN_DEV_N    IPADDR6
VLAN_DEV_%_METRIC        VLAN_DEV_%_DEFAULT     VLAN_DEV_N    NUMERIC

EOF

 # Set rights for check.d file
 chmod 0600 /etc/check.d/${package_name}
 chown root /etc/check.d/${package_name}
}
## -------------------------------------------------------------------------
### Create the exp file
### -------------------------------------------------------------------------
make_exp_file()
{
#--------------------------------------------------------------------------------
printgpl -check_exp ${package_name} ${DATUM} "OJae" "Olaf Jaehrling <eisfair[at]ojaehrling[dot]de>" >/etc/check.d/${package_name}.exp
#--------------------------------------------------------------------------------
cat >>/etc/check.d/${package_name}.exp <<EOF
VLAN_INTERFACE_CUI = '(RE:NOTEMPTY)' : 'please select a NIC'
VLAN_ADD = '()|(RE:IPADDR6)/(RE:NUMERIC)' : 'insert ipv6 address incl netmask'
VLAN_IP4 = '()|(RE:NETWORK)' : 'insert ipv4 address incl netmask'
EOF
 # Set rights for exp file
 chmod 0600 /etc/check.d/${package_name}.exp
 chown root /etc/check.d/${package_name}.exp
}
### -------------------------------------------------------------------------
### Create the ext file
### -------------------------------------------------------------------------

#make_ext_file()
#{
#--------------------------------------------------------------------------------
#printgpl -check_ext ${package_name} "2014-03-17" "OJae" "2014 Olaf Jaehrling <eisfair[at]ojaehrling[dot]de>" >/etc/check.d/${package_name}.ext
#--------------------------------------------------------------------------------
#cat >>/etc/check.d/${package_name}.ext <<EOF
#
#
#
#EOF
#
# # Set rights for exp file
# chmod 0600 /etc/check.d/${package_name}.ext
# chown root /etc/check.d/${package_name}.ext
#}



### ---------------------------------------------------------------------------
### Main
### ---------------------------------------------------------------------------

# update from old version
read_old_variables

# modify variables from old version
modify_variables

# write new config file
make_config_file /etc/config.d/${package}

# write default config file
make_config_file /etc/default.d/${package}
#make_default_file /etc/default.d/${package}

# write check.d file
make_check_file

# write *.exp file
make_exp_file

# write *.ext file
#make_ext_file

#anykey
exit 0

### ---------------------------------------------------------------------------
### End
###----------------------------------------------------------------------------

